"""System checks for sanic application."""

from typing import Awaitable, List

from ..utils.check_connection import (
    checkConnectionToInflux as _checkConnectionToInflux,
    checkExistingDocumentsDirectory as _checkExistingDocumentsDirectory,
)


async def checkExistingDocumentsDirectory() -> bool:
    """Make coroutine from function."""
    return _checkExistingDocumentsDirectory()


def getCheckConnectionToInflux(
    config: "BasePythonServiceSettingsClass",
    asyncCheck: bool = False,
) -> bool:
    """Get check connection to influx"""
    generalKwargs = {"host": config.monitoring.host, "port": config.monitoring.port, "ssl": config.monitoring.useSsl}
    monitoringCredentials = config.monitoring.credentials
    return _checkConnectionToInflux(
        organization=monitoringCredentials.organization,
        bucket=monitoringCredentials.bucket,
        token=monitoringCredentials.token,
        asyncCheck=asyncCheck,
        **generalKwargs,
    )


async def checkConnectionToInflux(config: "BasePythonServiceSettingsClass") -> bool:
    """Make coroutine from function."""
    return getCheckConnectionToInflux(config, asyncCheck=True)


def getChecks(config: "BasePythonServiceSettingsClass") -> List[Awaitable]:
    """Return list of system checks for sanic app."""
    checks = [checkExistingDocumentsDirectory()]
    if config.monitoring.sendData:
        checks.append(checkConnectionToInflux(config=config))

    return checks
